@@ -438,6 +438,8 @@ impl Date {
         clone
     }
 }
+
+/// # Iterators
 impl Edtf {
     // TODO: make iterators for OpenFrom/UnknownFrom that simply produce no output unless you
     // reverse them.
@@ -445,10 +447,7 @@ impl Edtf {
     fn interval(&self) -> Option<(Date, Date)> {
         match self {
             // These should work probably
-            Self::IntervalOpenTo(_d)
-            | Self::IntervalUnknownFrom(_d)
-            | Self::IntervalUnknownTo(_d)
-            | Self::IntervalOpenFrom(_d) => None,
+            Self::IntervalTo(_, _d) | Self::IntervalFrom(_d, _) => None,
             Self::Interval(d1, d2) => Some((*d1, *d2)),
             Self::Date(_) => None,
             Self::DateTime(_) => None,
