@@ -40,10 +40,3 @@ mod one {
         );
     }
 }
-
-mod version {
-    #[test]
-    fn test_readme_deps() {
-        version_sync::assert_markdown_deps_updated!("README.md");
-    }
-}
